# WifiScanner

## Description

WifiScanner is a advanced wifi vulnerability analysis module. It is can be used for router password cracking by WAN IP of the Router (Connection with another router of the same Ip is a must for PPPoE connection). Generating valid WAP IP address where http or another servers are running (by default http). You can also export the data in json or html format. [See The Documentations](https://github.com/Tonmoy-abc/WifiScanner/blob/main/md/uses.md)

#### Note: In the current version it will only work for Tp Link router

## How to install or installation
### Install with pip
```bash
pip install WifiScannerPro
```
### [Changelog](https://github.com/Tonmoy-abc/WifiScanner/blob/main/CHANGELOG.md)
